ArrayType class

Array avro type

Inheritance

Constructors

ArrayType({required AvroType items})
const
ArrayType.fromJson(Map<String, dynamic> json)
Create array from json schema
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
items → AvroType
Type of items
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(DataBuffer data) → List
Decode data for current type
override
encode(List payload) → Uint8List
Encode payload for current type
override
isType(dynamic payload) → bool
Is payload of current type
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited