EnumType class

Enum avro type

Inheritance

Constructors

EnumType({required String name, required String? namespace, required List<String> aliases, required String? doc, required List<String> symbols})
const
EnumType.fromJson(Map<String, dynamic> json)
Create enum from json schema
factory

Properties

aliases → List<String>
Aliases for backward schema compatibility
finalinherited
doc → String?
Documentation of enum
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of schema
finalinherited
namespace → String?
namespace of schema
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbols → List<String>
Enum values
final

Methods

decode(DataBuffer data) → String
Decode data for current type
override
encode(String payload) → Uint8List
Encode payload for current type
override
isType(dynamic payload) → bool
Is payload of current type
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited