BytesType class

Bytes avro type

Inheritance

Constructors

BytesType()
const
BytesType.fromJson()
Create Byte type from json
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(DataBuffer data) → Uint8List
Decode data for current type
override
encode(Uint8List payload) → Uint8List
Encode payload for current type
override
isType(dynamic payload) → bool
Is payload of current type
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited