LongType class

Long avro type

Inheritance

Constructors

LongType()
const
LongType.fromJson()
Create Long type from json
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(DataBuffer data) → int
Decode data for current type
inherited
encode(int payload) → Uint8List
Encode payload for current type
inherited
isType(dynamic payload) → bool
Is payload of current type
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited