AvroType<T> class abstract

abstract avro type

Implementers

Constructors

AvroType()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(DataBuffer data) → T
Decode data for current type
encode(T payload) → Uint8List
Encode payload for current type
isType(dynamic payload) → bool
Is payload of current type
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromDynamic(dynamic schema) → AvroType
Parse avro type from dynamic schema Used to manage raw string type, Json object type or List for union
fromJson(Map<String, dynamic> json) → AvroType
parse(String schema) → AvroType
Parse type from json Can parse raw string type like long