Schema class

Avro parsed schema

Constructors

Schema({required AvroType type})
const
Schema.fromJson(Map<String, dynamic> json)
Parse schema from decoded json
factory
Schema.parse(String schema)
Parse schema from json string Can also parse raw string type like string
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → AvroType
First type of schema
final

Methods

decode(Uint8List data) → dynamic
Decode data with current schema
encode(dynamic payload) → Uint8List
Encode payload with current schema
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited