DataBuffer class

Wrapper for ByteBuffer Used to keep count of offset while reading buffer

Constructors

DataBuffer(ByteBuffer buffer)

Properties

buffer → ByteBuffer
Buffer with data
final
hashCode → int
The hash code for this object.
no setterinherited
offset ↔ int
Current buffer offset
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

next(int length) → Uint8List
Get next length bytes from buffer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readBool() → bool
Read bool from buffer
readDouble() → double
Read double from buffer
readFloat() → double
Read float from buffer
readLong() → int
Read long/int from buffer
readString() → String
Read String from buffer
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited