DataWriterBuffer class

Wrapper for Uint8List Used to ensure buffer grow on use

Constructors

DataWriterBuffer()

Properties

buffer ↔ Uint8List
Buffer with data
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int i) → int
Get value from buffer at index i
operator []=(int i, int value) → void
Set value to buffer at index i